rhodes.curve: Logistic Curve Fitting by Rhodes Method
Description
This function fits the Logistic Curve in population Data by Rhodes Method along with estimates of the parameters and predicted value.
Usage
rhodes.curve(p)
Arguments
p
a numeric vector
Value
r.hat , L.hat , beta.hat : the estimated values of the parameters r, L and beta.
predicted.values : the predicted values of p
Details
Suppose we have n observations from population size corresponding to n equivalent time points say, at t=0,1,...,n-1. Here we assume the Logistic law of population growth , p=L/(1+exp(r*(beta-t))).